<?php
namespace Makeitneutral\MNL\Cron;

use Makeitneutral\MNL\Helper\Minhelp;
use Magento\Framework\Event\ObserverInterface;
use Magento\Directory\Model\CountryFactory;
use Magento\Framework\UrlInterface;
use Magento\Sales\Model\ResourceModel\Order;
use Magento\Sales\Model\ResourceModel\Order\CollectionFactory;
use Makeitneutral\MNL\Model\Service\Mnl\ApiData;

class SyncOrder
{
    protected $helper;
    protected $countryfactory;
    protected $urlinterface;
    protected $OrderResource;
    protected $_orderCollectionFactory;
	protected $apidata;
    protected $_logger;

    public function __construct(
        Minhelp $helper,
        Order $OrderResource,
        CountryFactory $countryfactory,
        UrlInterface $UrlInterface,
		ApiData $apidata,
        CollectionFactory $collectionFactory,
        \Psr\Log\LoggerInterface $logger
    ) {
        $this->helper = $helper;
        $this->_orderCollectionFactory = $collectionFactory;
        $this->OrderResource = $OrderResource;
        $this->countryfactory = $countryfactory;
        $this->urlinterface = $UrlInterface;
		$this->apidata = $apidata;
        $this->_logger = $logger;
    }

    public function execute()
    {
        $orders = $this->getOrderCollection();

        $productId = $this->helper->getConfig('mnl/general/product');
        foreach ($orders as $order) {
            $showcart = [];
            foreach ($order->getAllVisibleItems() as $item) {
                if ($item->getProductId() == $productId) {
                    $billingaddress = $order->getBillingAddress();
                
					$order_id = $order->getEntityId();
                    
					$params = array(
						"name" => trim($billingaddress->getFirstname()).' '.trim($billingaddress->getLastname()),
						"email" => trim($order->getCustomerEmail()),
						"amountoftrees" => (int)$item->getQtyOrdered()
					);
					
					$this->_logger->log(100,print_r($params,true));
					$sendOrder = $this->apidata->sendOrderToApi($order_id, $params);
					if ($sendOrder) {
						$order->setMakeitneutralSyncFailed(0);
					} else {
						$order->setMakeitneutralSyncFailed(1);
					}
					
                    $this->OrderResource->saveAttribute($order, 'makeitneutral_sync_failed');
                    $showcart['last_impression'] = true;
                    break;
                }
            }
        }
    }

    public function getOrderCollection()
    {
        $collection = $this->_orderCollectionFactory->create()
         ->addAttributeToSelect('*')
         ->addFieldToFilter('makeitneutral_sync_failed', ['eq'=>1]);
     
        return $collection;
    }
}
