<?php
namespace Makeitneutral\MNL\Helper;

use Magento\Framework\App\Helper\Context;
use Magento\Framework\Translate\Inline\StateInterface;
use Magento\Framework\Escaper;
use Magento\Framework\Mail\Template\TransportBuilder;
use Magento\Framework\App\Request\Http;
use Magento\Framework\App\ProductMetadataInterface;

class Minhelp extends \Magento\Framework\App\Helper\AbstractHelper
{
    protected $inlineTranslation;
    protected $escaper;
    protected $transportBuilder;
    protected $logger;
    protected $request;
    protected $productMetadata;

    public function __construct(
        Context $context,
        StateInterface $inlineTranslation,
        Escaper $escaper,
        Http $request,
        ProductMetadataInterface $ProductMetadata,
        TransportBuilder $transportBuilder
    ) {
        parent::__construct($context);
        $this->inlineTranslation = $inlineTranslation;
        $this->escaper = $escaper;
        $this->request = $request;
        $this->transportBuilder = $transportBuilder;
        $this->productMetadata = $ProductMetadata;
        $this->logger = $context->getLogger();
    }

    public function getConfig($config_path)
    {
        return $this->scopeConfig->getValue(
            $config_path,
            \Magento\Store\Model\ScopeInterface::SCOPE_STORE
        );
    }

    public function getModuleDisabled()
    {
        if ($this->request->getParam('makeitneutral') == true) {
            return false;
        }
        if ($this->getConfig('mnl/general/shop')) {
            return !$this->getConfig('mnl/general/enable');
        }

        return true;
    }

    public function getCartpageDisable()
    {
        if ($this->getModuleDisabled() != true) {
            $location = $this->getAvailableLocation();
            if (in_array('cart', $location)) {
                return false;
            }
        }
        return true;
    }

    public function getMiniCartpageDisable()
    {
        if ($this->getModuleDisabled() != true) {
            $location = $this->getAvailableLocation();
            if (in_array('mini_cart', $location)) {
                return false;
            }
        }
        return true;
    }


    public function getCheckoutpageDisable()
    {
        if ($this->getModuleDisabled() != true) {
            $location = $this->getAvailableLocation();
            if (in_array('checkout', $location)) {
                return false;
            }
        }
        return true;
    }

    public function getAvailableLocation()
    {
        $location = $this->getConfig('mnl/general/widget_location');
        return explode(",", $location);
    }

    public function getTemplateConfig()
    {
        if ($this->getMiniCartpageDisable()) {
            return 'Magento_Checkout/minicart/content';
        }
        if ($this->getConfig('mnl/general/enable') == 1) {
            if (version_compare($this->getMagentoVersion(), "2.3.6", "<=")) {
                return 'Makeitneutral_MNL/minicart/content234';
            } elseif (version_compare($this->getMagentoVersion(), "2.4.1", "<=")) {
                return 'Makeitneutral_MNL/minicart/content';
            }
        }

        return 'Magento_Checkout/minicart/content';
    }

    public function getMagentoVersion()
    {
        return $this->productMetadata->getVersion();
    }
}
