<?php

namespace Makeitneutral\MNL\Model;

use Magento\Catalog\Model\ProductFactory;
use Makeitneutral\MNL\Service\ImportImageService;
use Makeitneutral\MNL\Model\Service\SaveDashboard;
use Makeitneutral\MNL\Model\Service\Mnl\Countries;
use Magento\Framework\View\Asset\Repository;
use Magento\Framework\App\RequestInterface;
use Magento\Store\Model\StoreRepository;

class CreateProduct
{
    protected $product;
    protected $saveconfig;
    protected $image;
    protected $assetRepo;
    protected $request;
    protected $countries;
    protected $storeRepository;
    protected $logger;

    public function __construct(
        ProductFactory $product,
        SaveDashboard $saveconfig,
        ImportImageService $image,
        Countries $countries,
        Repository $assetRepo,
        RequestInterface $request,
        StoreRepository $StoreRepository,
        \Psr\Log\LoggerInterface $logger
    ) {
        $this->product = $product;
        $this->storeRepository = $StoreRepository;
        $this->image = $image;
        $this->countries = $countries;
        $this->assetRepo = $assetRepo;
        $this->saveconfig = $saveconfig;
        $this->request = $request;
        $this->logger = $logger;
    }

    public function CreateProduct()
    {
		$filename = "makeitneutral.png";
        $params = ['_secure' => $this->request->isSecure()];
        $imageUrl = $this->assetRepo->getUrlWithParams('Makeitneutral_MNL::images/'.$filename, $params);
        $taxId = 2;
        try {
            $product = $this->getProduct();
            $product->setName('Makeitneutral Fee');
            $product->setAttributeSetId(4);
            $product->setWebsiteIds($this->getWebsite());
            $product->setStatus(1);
            $product->setShortDescription("Plant a tree to make your order a bit more carbon neutral. Positive and support your local forests.");
            $product->setDescription("Plant a tree to make your order forest positive and a bit more carbon neutral. Positive and support your local forests.");
            $product->setVisibility(1);
            $product->setTaxClassId($taxId);
            $product->setTypeId(\Magento\Catalog\Model\Product\Type::TYPE_VIRTUAL);
            $product->setPrice($this->saveconfig->getConfig("mnl/general/fee"));
            $product->setUrlKey('makeitneutral-fee-'.strtotime("now"));
            $product->setStockData(
                [
                    'use_config_manage_stock' => 0,
                    'manage_stock' => 0,
                    'is_in_stock' => 1,
                    'use_config_max_sale_qty'=> 1,
                ]
            );

            $this->image->execute($product, $imageUrl, true, ['image', 'small_image', 'thumbnail']);
            $product->save();
            $this->saveconfig->saveConfig('mnl/general/product', $product->getId());
        } catch (\Exception $e) {
            $this->logger->error($e->getMessage());
        }
        return $product;
    }

    public function getWebsite()
    {
        $stores = $this->storeRepository->getList();
        $websiteIds = [];
        foreach ($stores as $store) {
            $websiteId = $store["website_id"];
            array_push($websiteIds, $websiteId);
        }

        return $websiteIds;
    }

    public function UpdateProductImage($value)
    {
        $productId = $this->saveconfig->getConfig("mnl/general/product");
        $filename = "cloud-".$value.".png";
        $params = ['_secure' => $this->request->isSecure()];
        $imageUrl = $this->assetRepo->getUrlWithParams('Makeitneutral_MNL::images/'.$filename, $params);
        try {
            $product = $this->product->create();
            if ($productId) {
                $product->load($productId);
                $this->image->execute($product, $imageUrl, false, ['image', 'small_image', 'thumbnail']);
                $product->save();
            }
        } catch (\Exception $e) {
            $this->logger->error($e->getMessage());
        }
        return $product;
    }

    public function UpdatePrice($price)
    {
        $productId = $this->saveconfig->getConfig("mnl/general/product");
        $taxId = $this->countries->getStoretaxable() == 1 ? 2 : 0;
        try {
            $product = $this->product->create();
            if ($productId) {
                $product->load($productId);
                $product->setPrice($price);
                $product->setTaxClassId($taxId);
                $product->setStockData(
                    [
                        'use_config_manage_stock' => 0,
                        'manage_stock' => 0,
                        'is_in_stock' => 1,
                        'use_config_max_sale_qty'=> 1
                    ]
                );
                $product->save();
            }
        } catch (\Exception $e) {
            $this->logger->error($e->getMessage());
        }
        return $product;
    }

    public function UpdateStatus($status)
    {
        $productId = $this->saveconfig->getConfig("mnl/general/product");
        try {
            $product = $this->product->create();
            if ($productId) {
                $product->load($productId);
                $product->setStatus($status == 0 ? 2 : $status);
                $product->save();
            }
        } catch (\Exception $e) {
            $this->logger->error($e->getMessage());
        }
        return $product;
    }

    public function getProduct()
    {
        $model = $this->product->create();
        $product = $model->loadByAttribute('sku', 'makeitneutral-fee');
        if ($product && $product->getId()) {
            return $product;
        }
        $model->setSku("makeitneutral-fee");
        return $model;
    }
}
