<?php

namespace Makeitneutral\MNL\Model\Service\Mnl;

class ApiData extends Authentication
{
	
	public function getAPIsettings(){
		
		$options = $this->getSettingOptions();
		
		if(empty($options['mnl_general_title']) || empty($options['mnl_general_text']) || empty($options['mnl_general_linkname']) || empty($options['mnl_general_linkurl'])){
			$options = $this->getAPIdefaultOptions($options['mnl_general_api_url'], $options); 
		}
		
		return $options;
	}
	
	public function getSettingOptions(){
		
		$options = array();
		$mnl_general_enable = $this->getConfig("mnl/general/enable");
		$options["mnl_general_enable"] = (int)$mnl_general_enable;
		
		$mnl_general_apikey = $this->getConfig("mnl/general/apikey");
		$options["mnl_general_apikey"] = $mnl_general_apikey;
		
		$mnl_general_testmode = $this->getConfig("mnl/general/testmode");
		$options["mnl_general_testmode"] = (int)$mnl_general_testmode;
		
		$mnl_general_title = $this->getConfig("mnl/general/title");
		$options["mnl_general_title"] = $mnl_general_title;
		
		$mnl_general_text = $this->getConfig("mnl/general/text");
		$options["mnl_general_text"] = $mnl_general_text;
		
		$mnl_general_linkname = $this->getConfig("mnl/general/linkname");
		$options["mnl_general_linkname"] = $mnl_general_linkname;
		
		$mnl_general_linkurl = $this->getConfig("mnl/general/linkurl");
		$options["mnl_general_linkurl"] = $mnl_general_linkurl;
		
		$options['mnl_general_api_url'] = self::MAKEITNEUTRAL_CONFIG_URL;
		if ($options && isset($options['mnl_general_testmode']) && (int)$options['mnl_general_testmode'] > 0) $options['mnl_general_api_url'] = self::MAKEITNEUTRAL_CONFIG_URL_TEST;
		
		return $options;
	}
	
	public function getApiOrders(){
		
		$orderdata = array();
		$APIsettings = $this->getAPIsettings();
		
		if(isset($APIsettings["mnl_general_apikey"]) && !empty($APIsettings["mnl_general_apikey"]) && isset($APIsettings["mnl_general_api_url"]) && !empty($APIsettings["mnl_general_api_url"])){
			$_api_url = $APIsettings["mnl_general_api_url"];
			try {
				$params = [
				  'key' => $APIsettings["mnl_general_apikey"]
				];
				
				$this->curl->setOption(CURLOPT_TIMEOUT, 0);
				$this->curl->setOption(CURLOPT_RETURNTRANSFER, true);
				$this->curl->addHeader("Content-Type", "application/json");
				$this->curl->addHeader("Accept", "application/json");
				$this->curl->post($APIsettings["mnl_general_api_url"].'get_orders', $this->jsonHelper->jsonEncode($params));
				$response = $this->curl->getBody();
				
				if ($this->curl->getStatus() == 200) {
					
					$response = $this->jsonHelper->jsonDecode($response);
					
					if ($response && is_array($response) && count($response) > 0) {
						$orderdata = $response;
					}
				} else {
					throw new \Exception($response);
				}
			} catch (\Exception $e) {
				$this->logger->error($e->getMessage());
				$this->messageManager->addError($e->getMessage());
				return;
			}
		}
		
		return $orderdata;
	}
	
	public function sendOrderToApi($order_id = 0, $order_data = array()){
		
		$return = false;
		if($order_id <= 0) return $return;
		if(empty($order_data)) return $return;
		
		$options = $this->getSettingOptions();
		
		if ($options && isset($options['mnl_general_apikey']) && $options['mnl_general_apikey']) {
			try {
				$params = array(
					"key" => $options['mnl_general_apikey'],
					"customer_name" => $order_data["name"],
					"customer_email" => $order_data["email"],
					"amount" => $order_data["amountoftrees"],
					"shop" => $this->storeManager->getStore()->getBaseUrl(\Magento\Framework\UrlInterface::URL_TYPE_WEB)
				);
				
				$this->curl->setOption(CURLOPT_TIMEOUT, 0);
				$this->curl->setOption(CURLOPT_RETURNTRANSFER, true);
				$this->curl->addHeader("Content-Type", "application/json");
				$this->curl->addHeader("Accept", "application/json");
				$this->curl->post($options["mnl_general_api_url"].'order', $this->jsonHelper->jsonEncode($params));
				$response = $this->curl->getBody();
				
				 if ($this->curl->getStatus() == 200) {
					  $response = $this->jsonHelper->jsonDecode($response);
					  if ($response && is_array($response) && isset($response['status']) && $response['status'] == 'ok') {
						  $return = true;
					  }
				  } else {
					  throw new \Exception($response);
				  }
			} catch (\Exception $e) {
				$this->logger->error($e->getMessage());
				return;
			}

		}
		
		return $return;
	}
	
	public function getAPIdefaultOptions($_api_url, $_options){
		$params = array();
		
		try {
			$this->curl->setOption(CURLOPT_HEADER, 0);
            $this->curl->setOption(CURLOPT_TIMEOUT, 0);
            $this->curl->setOption(CURLOPT_MAXREDIRS, 10);
            $this->curl->setOption(CURLOPT_RETURNTRANSFER, true);
            $this->curl->addHeader("Content-Type", "application/json");
            $this->curl->addHeader("Accept", "application/json");
            $this->curl->get($_api_url.'get_options');
            $response = $this->curl->getBody();
            if ($this->curl->getStatus() == 200) {
				$response = $this->jsonHelper->jsonDecode($response);
				
				if ($response && is_array($response) && count($response) > 0) {
					if(empty($_options['mnl_general_title']) && isset($response["title"])){
						$_options['mnl_general_title'] = $response["title"];
						$this->configWriter->save("mnl/general/title", $_options['mnl_general_title']);
					};
					if(empty($_options['mnl_general_text']) && isset($response["text_eur"])){ 
						$_options['mnl_general_text'] = $response["text_eur"];
						$this->configWriter->save("mnl/general/text", $_options['mnl_general_text']);
					};
					
					$_options['mnl_general_fee'] = $response["fee"];
					$this->configWriter->save("mnl/general/fee", $_options['mnl_general_fee']);
					
				}
            } else {
                throw new \Exception($response);
            }
        } catch (\Exception $e) {
            $this->logger->error($e->getMessage());
            $this->messageManager->addError($e->getMessage());
            return;
        }
		
		return $_options;
	}
   
}
